#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
import letmego

from src import sleep, log
from src import Src
from src.custom_exception import ElementNotFound
from public.dde_launcher_public_widget.config import Config

@letmego.mark
@log
# pylint: disable=too-many-ancestors
class DdeLauncherPublicWidget(Src):
    """启动器的方法类"""

    APP_NAME = "dde-launcher"
    DESC = "/usr/bin/dde-launcher"

    def __init__(self):
        kwargs = {}
        kwargs["name"] = self.APP_NAME
        kwargs["description"] = self.DESC
        kwargs["check_start"] = True
        kwargs["config_path"] = Config.UI_INI_PATH
        Src.__init__(self, **kwargs)

    def click_and_input_search_edit_in_launcher_by_attr(self, text):
        """
         在启动器中点击搜索，然后输入
        :param text: 输入的文本
        :return:
        """
        try:
            self.dog.app_element("Form_windowedsearcheredit").click()
        except ElementNotFound:
            self.dog.app_element("Form_searcheredit").click()
        sleep(0.5)
        self.input_message(text)
        sleep(0.5)

    def click_search_edit_on_launcher_by_attr(self):
        """
         移动到启动器上
        :return:
        """
        try:
            self.dog.app_element("Form_windowedsearcheredit").click()
        except ElementNotFound:
            self.dog.app_element("Form_searcheredit").click()

    def click_app_in_lancher_by_attr(self, app_name):
        """
         在启动器中点击应用
        :param app_name: 应用名
        :return:
        """
        self.dog.app_element(f"{app_name}").click()

    def double_click_app_in_lancher_by_attr(self, app_name):
        """
         在启动器中双击应用
        :param app_name: 应用名
        :return:
        """
        self.dog.app_element(f"{app_name}").doubleClick()

    def right_click_app_in_lancher_by_attr(self, app_name):
        """
         在启动器中右键点击应用
        :param app_name: 应用名
        :return:
        """
        self.dog.app_element(f"{app_name}").click(3)

    def select_music_right_menu_in_launcher(self, num):
        """
         在启动器中选择音乐的右键菜单
        :param num: 菜单的第几项
        :return:
        """
        self.click_and_input_search_edit_in_launcher_by_attr("音乐")
        sleep(1)
        self.right_click_app_in_lancher_by_attr("音乐")
        self.select_menu(num)
        sleep(1)

    def click_music_in_launcher_by_attr(self):
        """
         在启动器中点击音乐
        :return:
        """
        self.click_app_in_lancher_by_attr("音乐")

    def click_open_file_manager_in_launcher_by_attr(self):
        """
         在启动器中点击文管
        :return:
        """
        self.click_and_input_search_edit_in_launcher_by_attr("文件管理器")
        self.click_app_in_lancher_by_attr("文件管理器")

    def click_screen_recorder_in_launcher_by_attr(self):
        """
         在启动器中点击截图录屏
        :return:
        """
        self.click_and_input_search_edit_in_launcher_by_attr("截图录屏")
        self.click_app_in_lancher_by_attr("截图录屏")

    def send_file_manager_to_desktop_in_launcher_by_attr(self):
        """
         在launcher中发送到桌面
        :return:
        """
        self.click_and_input_search_edit_in_launcher_by_attr("文件管理器")
        self.right_click_app_in_lancher_by_attr("文件管理器")
        self.select_menu(2)
        sleep(1)

    def open_file_manager_in_launcher_by_right_menu(self):
        """
         在启动器中右键打开应用
        :return:
        """
        self.click_and_input_search_edit_in_launcher_by_attr("文件管理器")
        self.right_click_app_in_lancher_by_attr("文件管理器")
        self.select_menu(1)
        sleep(1)



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
import letmego

from src import Src
from src import log
from public.right_menu_public_widget.right_menu_public_widget import (
    RightMenuPublicWidget,
)
from public.other_public_widget.config import Config

@letmego.mark
@log
# pylint: disable=too-many-ancestors
class DeepinCompressPublicWidget(Src, RightMenuPublicWidget):
    """DeepinCompressPublicWidget"""

    APP_NAME = "deepin-compressor"
    DESC = "/usr/bin/deepin-compressor"

    def __init__(self):
        kwargs = {}
        kwargs["name"] = self.APP_NAME
        kwargs["description"] = self.DESC
        kwargs["check_start"] = True
        kwargs["config_path"] = Config.UI_INI_PATH
        Src.__init__(self, **kwargs)

    def click_compress_btn_in_compress_window_by_ui(self):
        """
         点击压缩按钮
        :return:
        """
        self.click(*self.ui.btn_center("压缩按钮"))

    def click_save_to_btn_in_compress_window_by_ui(self):
        """
         点击保存到按钮
        :return:
        """
        self.click(*self.ui.btn_center("保存到按钮"))

    def click_replace_btn_in_compress_window_by_ui(self):
        """
         压缩同名提示，点击替换按钮
        :return:
        """
        self.click(*self.ui.btn_center("替换按钮"))

    @classmethod
    def close_compress_by_cmd(cls):
        """
         关闭压缩
        :return:
        """
        cls.kill_process("deepin-compressor")



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
# pylint: disable=C0301,C0103,R0904
from time import sleep
from src.mouse_key import MouseKey
from src  import log


@log
class ShortCut(MouseKey):
    """快捷键"""

    @classmethod
    def ctrl_f9(cls):
        """
         ctrl_f9 快捷键设置壁纸
        :return:
        """
        cls.hot_key("ctrl", "f9")

    @classmethod
    def super_up(cls):
        """
         super_up 最大化窗口
        :return:
        """
        cls.hot_key("win", "up")

    @classmethod
    def win_left(cls):
        """
        win_left  向左切换工作区
        :return:
        """
        cls.hot_key("win", "left")

    @classmethod
    def win_right(cls):
        """
         win_right 向右切换工作区
        :return:
        """
        cls.hot_key("win", "Right")

    @classmethod
    def ctrl_shift_shortcut_down(cls):
        """
         ctrl shift ? 唤起快捷键面板
        :return:
        """
        cls.hot_key_down("ctrl", "shift", "/")

    @classmethod
    def ctrl_shift_shortcut_up(cls):
        """
         ctrl shift ? 收起快捷键面板
        :return:
        """
        cls.hot_key_up("ctrl", "shift", "/")

    @classmethod
    def shift_right(cls):
        """
         'shift' + 'right'
        :return:
        """
        cls.hot_key("shift", "right")

    @classmethod
    def shift_down(cls):
        """
         shift_down
        :return:
        """
        cls.hot_key("shift", "down")

    @classmethod
    def shift_up(cls):
        """
         shift_up
        :return:
        """
        cls.hot_key("shift", "up")

    @classmethod
    def tab(cls):
        """
         tab
        :return:
        """
        cls.press_key("tab")

    @classmethod
    def esc(cls):
        """
         esc
        :return:
        """
        cls.press_key("esc")

    @classmethod
    def right(cls):
        """
         right 键盘方向键-右键
        :return:
        """
        cls.press_key("right")

    @classmethod
    def left(cls):
        """
         left 键盘方向键-左键
        :return:
        """
        cls.press_key("left")

    @classmethod
    def dot(cls):
        """
         dot 键盘点号
        :return:
        """
        cls.press_key(".")

    @classmethod
    def press_left_sometime(cls, sometime: int):
        """
         按住键盘方向键-左键一段时间
        :param sometime: 一段时间
        :return:
        """
        cls.press_key_down("left")
        sleep(sometime)
        cls.press_key_up("left")

    @classmethod
    def up(cls):
        """
         up 键盘方向键-上键
        :return:
        """
        cls.press_key("up")

    @classmethod
    def press_up_sometime(cls, sometime: int):
        """
         按住键盘方向键-上键一段时间
        :param sometime: 一段时间
        :return:
        """
        cls.press_key_down("up")
        sleep(sometime)
        cls.press_key_up("up")

    @classmethod
    def down(cls):
        """
         down 键盘方向键-下键
        :return:
        """
        cls.press_key("down")

    @classmethod
    def enter(cls):
        """
         enter 回车
        :return:
        """
        cls.press_key("enter")

    @classmethod
    def ctrl_a(cls):
        """
         ctrl_a
        :return:
        """
        cls.hot_key("ctrl", "a")

    @classmethod
    def ctrl_g(cls):
        """
         ctrl_g
        :return:
        """
        cls.hot_key("ctrl", "g")

    @classmethod
    def ctrl_n(cls):
        """
         ctrl_n
        :return:
        """
        cls.hot_key("ctrl", "n")

    @classmethod
    def ctrl_alt_t(cls):
        """
         ctrl_alt_t
        :return:
        """
        cls.hot_key("ctrl", "alt", "t")

    @classmethod
    def ctrl_alt_down(cls):
        """
         ctrl_alt_down
        :return:
        """
        cls.hot_key("ctrl", "alt", "down")

    @classmethod
    def ctrl_alt_up(cls):
        """
         ctrl_alt_up
        :return:
        """
        cls.hot_key("ctrl", "alt", "up")

    @classmethod
    def ctrl_alt_a(cls):
        """
         ctrl_alt_a
        :return:
        """
        cls.hot_key("ctrl", "alt", "a")

    @classmethod
    def ctrl_x(cls):
        """
         ctrl_x
        :return:
        """
        cls.hot_key("ctrl", "x")

    @classmethod
    def ctrl_s(cls):
        """
         ctrl_a
        :return:
        """
        cls.hot_key("ctrl", "s")

    @classmethod
    def alt_tab(cls):
        """
         快捷键alt+table
        :return:
        """
        cls.hot_key("alt", "tab")

    @classmethod
    def alt_m(cls):
        """
         ctrl_m
        :return:
        """
        cls.hot_key("alt", "m")

    @classmethod
    def ctrl_f(cls):
        """
         ctrl_f
        :return:
        """
        cls.hot_key("ctrl", "f")

    @classmethod
    def ctrl_v(cls):
        """
         ctrl_v
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "v")

    @classmethod
    def ctrl_c(cls):
        """
         ctrl_c
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "c")

    @classmethod
    def alt_f4(cls):
        """
         alt_f4
        :return:
        """
        sleep(1)
        cls.hot_key("alt", "f4")

    @classmethod
    def alt_f2(cls):
        """
         alt_f2
        :return:
        """
        sleep(1)
        cls.hot_key("alt", "f2")

    @classmethod
    def f2(cls):
        """
         f2
        :return:
        """
        sleep(1)
        cls.press_key("f2")

    @classmethod
    def f1(cls):
        """
         f1
        :return:
        """
        sleep(1)
        cls.press_key("f1")

    @classmethod
    def f3(cls):
        """
         f3
        :return:
        """
        sleep(1)
        cls.press_key("f3")

    @classmethod
    def f5(cls):
        """
         f5
        :return:
        """
        sleep(1)
        cls.press_key("f5")

    @classmethod
    def space(cls):
        """
         space
        :return:
        """
        sleep(1)
        cls.press_key("space")

    @classmethod
    def backspace(cls):
        """
         backspace
        :return:
        """
        sleep(1)
        cls.press_key("backspace")

    @classmethod
    def winleft_d(cls):
        """
         winleft_d
        :return:
        """
        sleep(1)
        cls.hot_key("winleft", "d")

    @classmethod
    def ctrl_z(cls):
        """
         ctrl_z
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "z")
        sleep(0.5)

    @classmethod
    def ctrl_y(cls):
        """
         ctrl_y
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "y")
        sleep(0.5)

    @classmethod
    def winleft_e(cls):
        """
         winleft_e
        :return:
        """
        sleep(1)
        cls.hot_key("winleft", "e")

    @classmethod
    def delete(cls):
        """
         delete
        :return:
        """
        cls.press_key("delete")

    @classmethod
    def shift_delete(cls):
        """
         shift_delete
        :return:
        """
        cls.hot_key("shift", "delete")

    @classmethod
    def shift_left(cls):
        """
         shift+左方向键
        :return:
        """
        cls.hot_key("shift", "left")

    @classmethod
    def ctrl_i(cls):
        """
         ctrl i
        :return:
        """
        cls.hot_key("ctrl", "i")

    @classmethod
    def ctrl_h(cls):
        """
         ctrl h
        :return:
        """
        cls.hot_key("ctrl", "h")

    @classmethod
    def ctrl_o(cls):
        """
         ctrl_o
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "o")

    @classmethod
    def ctrl_shift_up(cls):
        """
         ctrl_shift_up
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "shift", "up")

    @classmethod
    def ctrl_shift_n(cls):
        """
         ctrl_shift_n
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "shift", "n")

    @classmethod
    def ctrl_shift_down(cls):
        """
         ctrl_shift_down
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "shift", "down")

    @classmethod
    def ctrl_shift_left(cls):
        """
         ctrl_shift_left
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "shift", "left")

    @classmethod
    def ctrl_shift_right(cls):
        """
         ctrl_shift_right
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "shift", "right")

    @classmethod
    def ctrl_up(cls):
        """
         ctrl_up
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "up")

    @classmethod
    def ctrl_down(cls):
        """
         ctrl_down
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "down")

    @classmethod
    def ctrl_left(cls):
        """
         ctrl_left
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "left")

    @classmethod
    def ctrl_right(cls):
        """
         ctrl_right
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "right")

    @classmethod
    def shift_space(cls):
        """
         shift+space
        :return:
        """
        sleep(1)
        cls.hot_key("shift", "space")

    @classmethod
    def ctrl_rod(cls):
        """
         ctrl+-
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "-")

    @classmethod
    def ctrl_add(cls):
        """
         ctrl++
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "+")

    @classmethod
    def ctrl_r(cls):
        """
         ctrl+r
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "r")

    @classmethod
    def ctrl_shift_r(cls):
        """
         ctrl+shift+r
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "shift", "r")

    @classmethod
    def ctrl_shift_z(cls):
        """
         ctrl+shift+z
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "shift", "z")

    @classmethod
    def ctrl_scroll(cls, direction, amount_of_scroll=1):
        """
         ctrl+滚轮
        :param direction:
        :param amount_of_scroll:
        :return:
        """
        cls.press_key_down("ctrl")
        for _ in range(amount_of_scroll):
            cls.mouse_scroll(direction, duration=0)
        cls.press_key_up("ctrl")

    @classmethod
    def shift_scroll(cls, direction, amount_of_scroll=1):
        """
         shift+滚轮
        :param direction:
        :param amount_of_scroll:
        :return:
        """
        cls.press_key_down("shift")
        for _ in range(amount_of_scroll):
            cls.mouse_scroll(direction, duration=0)
        cls.press_key_up("shift")

    @classmethod
    def alt_d(cls):
        """
         alt+d
        :return:
        """
        sleep(1)
        cls.hot_key("alt", "d")

    @classmethod
    def ctrl_e(cls):
        """
         ctrl+e
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "e")

    @classmethod
    def ctrl_shift_s(cls):
        """
         ctrl+shift+s
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "shift", "s")

    @classmethod
    def ctrl_alt_v(cls):
        """
         快捷键打开剪切板
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "alt", "v")

    @classmethod
    def ctrl_printscreen(cls):
        """
         快捷键启动延时截图
        :return:
        """
        sleep(1)
        cls.hot_key("ctrl", "printscreen")

    @classmethod
    def alt_enter(cls):
        """
         快捷键影院进入全屏
        :return:
        """
        sleep(1)
        cls.hot_key("alt", "enter")

    @classmethod
    def printscreen(cls):
        """
         快捷键截取全屏
        :return:
        """
        sleep(1)
        cls.hot_key("printscreen")

    @classmethod
    def alt_o(cls):
        """
         ocr应用内部快捷键
        :return:
        """
        sleep(1)
        cls.hot_key("alt", "o")

    @classmethod
    def alt_s(cls):
        """
         快捷键连拍截图
        :return:
        """
        sleep(1)
        cls.hot_key("alt", "s")

    @classmethod
    def alt_p(cls):
        """
         贴图应用内部快捷键
        :return:
        """
        sleep(1)
        cls.hot_key("alt", "p")

    @classmethod
    def p(cls):
        """
         按下p快捷键
        :return:
        """
        sleep(1)
        cls.press_key("p")

    @classmethod
    def h(cls):
        """
         按下h快捷键
        :return:
        """
        sleep(1)
        cls.press_key("h")

    @classmethod
    def f(cls):
        """
         按下f快捷键
        :return:
        """
        sleep(1)
        cls.press_key("f")

    @classmethod
    def s(cls):
        """
         按下s快捷键
        :return:
        """
        sleep(1)
        cls.press_key("s")

    @classmethod
    def o(cls):
        """
         按下o快捷键
        :return:
        """
        sleep(1)
        cls.press_key("o")

    @classmethod
    def r(cls):
        """
         按下r快捷键
        :return:
        """
        sleep(1)
        cls.press_key("r")

    @classmethod
    def i(cls):
        """
         按下i快捷键
        :return:
        """
        sleep(1)
        cls.press_key("i")

    @classmethod
    def alt_shift_tab(cls):
        """
         快捷键切换应用窗口
        :return:
        """
        cls.hot_key("alt", "shift", "tab")

    @classmethod
    def alt_printscreen(cls):
        """
         快捷键 <alt + PrintScreen>
        :return:
        """
        cls.hot_key("alt", "PrintScreen")

    @classmethod
    def super_d(cls):
        """快捷键 super + d
        :return:
        """
        cls.hot_key("win", "d")

    @classmethod
    def pageup(cls):
        """
         上一页
        :return:
        """
        cls.press_key("pageup")

    @classmethod
    def pagedown(cls):
        """
         下一页
        :return:
        """
        cls.press_key("pagedown")



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
import os
from time import sleep

from src  import logger
from src.cmdctl import CmdCtl

os.environ["DISPLAY"] = ":0"
# pylint: disable=C0103,R0904,C0411
# pylint: disable=wrong-import-position
from setting.globalconfig import GlobalConfig

if GlobalConfig.IS_WAYLAND:
    # pylint: disable=ungrouped-imports
    from src.depends.pyautogui import _pyautogui_wayland as pyautogui
    from src.depends.pyautogui._pyautogui_wayland import popen
else:
    from src.depends import pyautogui

pyautogui.FAILSAFE = False


# pyautogui.PAUSE = 1


class MouseKey:
    """
    鼠标和键盘的常用操作
    """

    __author__ = "Mikigo <huangmingqiang@uniontech.com>, Litao <litaoa@uniontech.com>"

    MOUSE = {1: pyautogui.PRIMARY, 2: pyautogui.MIDDLE, 3: pyautogui.RIGHT}

    @classmethod
    def screen_size(cls):
        """
         获取屏幕大小
        :return: width, height
        """
        width, height = pyautogui.size()
        logger.debug(f"获取屏幕分辨率 {width}*{height}")
        return width, height

    @classmethod
    def current_location(cls, out_log=True):
        """
         获取当前鼠标位置
        :return: 鼠标当前的坐标
        """
        position = pyautogui.position()
        if out_log:
            logger.debug(f"当前鼠标坐标 {position}")
        return position

    # @classmethod
    # def input_chinese(cls, text, delay_time=300):
    #     """
    #     输入中文
    #     """
    #     CmdCtl.run_cmd(f"xdotool type --delay {delay_time} '{text}'", timeout=60)
    #     logger.debug(f"输入文本 {text}")
    #     sleep(1)

    @classmethod
    def move_to(cls, _x, _y, duration=0.4):
        """
         移动到指定位置
        :param _x: x
        :param _y: y
        :param duration:移动的速度
        :return:
        """
        logger.debug(f"鼠标移动至 ({_x, _y}, 速度：{duration})")
        pyautogui.moveTo(int(_x), int(_y), duration=duration)

    @classmethod
    def move_rel(cls, _x, _y, duration=0.4):
        """
         相对移动到位置
        :param _x:
        :param _y:
        :param duration:
        :return:
        """
        logger.debug(f"鼠标移动相对坐标位置 ({_x, _y}), 速度：{duration}")
        pyautogui.moveRel(xOffset=int(_x), yOffset=int(_y), duration=duration)

    @classmethod
    def click(cls, _x=None, _y=None, _type="pyautogui"):
        """
         点击鼠标左键
        :param _x:
        :param _y:
        :param _type: 使用 PyAutoGUI or Xdotool 点击
        :return:
        """
        logger.debug(f"点击坐标 {(_x, _y) if _x else cls.current_location(out_log=False)}")
        if _type == "pyautogui":
            pyautogui.click(x=_x, y=_y)
        else:
            if GlobalConfig.IS_WAYLAND:
                pyautogui.click(x=_x, y=_y)
            else:
                CmdCtl.run_cmd(f"xdotool mousemove {_x} {_y} click 1")

    @classmethod
    def move_rel_and_click(cls, _x, _y):
        """
         move relative and click
        :param _x:
        :param _y:
        :return:
        """
        cls.move_rel(_x, _y)
        cls.click()

    @classmethod
    def middle_click(cls):
        """
        单击鼠标滚轮中间
        """
        logger.debug("单击鼠标滚轮中间")
        pyautogui.middleClick()

    @classmethod
    def right_click(cls, _x=None, _y=None):
        """
         单击鼠标右键
        :param _x:
        :param _y:
        :return:
        """
        logger.debug(
            f"鼠标右键坐标 {(_x, _y) if _x else cls.current_location(out_log=False)}"
        )
        pyautogui.rightClick(x=_x, y=_y)
        sleep(1)

    @classmethod
    def double_click(cls, _x=None, _y=None, interval=0.3):
        """
         双击鼠标左键
        :param _x:
        :param _y:
        :param interval: 两次点击的间隔，默认 0.3s
        :return:
        """
        logger.debug(
            f"鼠标左键双击坐标 {(_x, _y) if _x else cls.current_location(out_log=False)}"
        )
        pyautogui.doubleClick(x=_x, y=_y, interval=interval)
        # CmdCtl.run_cmd(f"xdotool mousemove {_x} {_y} click --repeat 2 1")
        sleep(1)

    @classmethod
    def triple_click(cls, _x=None, _y=None):
        """
         三击鼠标左键
        :param _x:
        :param _y:
        :return:
        """
        logger.debug(
            f"鼠标三连击坐标 {(_x, _y) if _x else cls.current_location(out_log=False)}"
        )
        pyautogui.tripleClick(x=_x, y=_y, interval=0.3)
        sleep(1)

    @classmethod
    def drag_to(cls, _x, _y, duration=0.4, delay=1):
        """
         拖拽到指定位置(绝对位置)
        :param _x: 拖拽到的位置x
        :param _y: 拖拽到的位置y
        :param duration: 拖拽的时常
        :param delay: 拖拽后等待的时间
        :return:
        """
        logger.debug(f"鼠标从当前位置拖拽到坐标 ({_x, _y})")
        pyautogui.dragTo(x=int(_x), y=int(_y), duration=duration, mouseDownUp=True)
        sleep(delay)

    @classmethod
    def drag_rel(cls, _x, _y):
        """
         按住鼠标左键,拖拽到指定位置(相对位置)
        :param _x: 拖拽的相对位置x，正数向右，负数向左
        :param _y: 拖拽的相对位置y，正数向下，负数向上
        :return:
        """
        logger.debug(f"鼠标从当前位置拖拽到相对坐标 ({_x, _y})")
        pyautogui.dragRel(
            xOffset=int(_x), yOffset=int(_y), duration=0.4, mouseDownUp=True
        )
        sleep(1)

    @classmethod
    def mouse_down(cls, _x=None, _y=None, button=1):
        """
         按住鼠标键不放
        :param _x:
        :param _y:
        :param button: 1 左键， 2 中键， 3 右键
        :return:
        """
        logger.debug(
            f"在坐标 {(_x, _y) if _x else cls.current_location(out_log=False)} "
            f"处按住鼠标{['左', '中', '右'][button - 1]}键不放"
        )
        pyautogui.mouseDown(x=_x, y=_y, button=cls.MOUSE.get(button, pyautogui.PRIMARY))
        sleep(1)

    @classmethod
    def mouse_up(cls, button=1):
        """
         松开鼠标左键
        :param button: 1 左键， 2 中键， 3 右键
        :return:
        """
        logger.debug(f"松开鼠标{['左', '中', '右'][button - 1]}键")
        pyautogui.mouseUp(button=cls.MOUSE.get(button, pyautogui.PRIMARY))
        sleep(1)

    @classmethod
    def mouse_scroll(cls, amount_of_scroll, duration=1):
        """
         滚动鼠标滚轮,the_amount_of_scroll为传入滚轮数,正数为向上,负数为向下
        :param amount_of_scroll: 滚轮数
        :param duration:
        :return:
        """
        pyautogui.scroll(amount_of_scroll)
        if amount_of_scroll > 0:
            direct = "上"
        else:
            direct = "下"
        logger.debug(f"向<{direct}>滑动滚轮")
        sleep(duration)

    @classmethod
    def input_message(cls, message, delay_time=300, interval=0.2, wayland_shift=False):
        """
         输入字符串
        :param message: 输入的内容
        :param delay_time: 延迟时间
        :param interval:
        :return:
        """
        logger.debug(f"输入字符串<{message}>")
        message = str(message)

        def check_chinese():
            for _ch in message:
                if "\u4e00" <= _ch <= "\u9fff":
                    return True
            return False

        if GlobalConfig.IS_X11:
            if check_chinese():
                CmdCtl.run_cmd(
                    f"xdotool type --delay {delay_time} '{message}'", timeout=60
                )
            else:
                pyautogui.typewrite(message=str(message), interval=interval)
        # wayland上
        else:
            # 复制
            if os.popen("ps -aux |  grep wayland_autotool | grep -v grep").read():
                # 先杀掉
                CmdCtl.run_cmd("kill -9 $(pidof wayland_autotool)", interrupt=False)
                sleep(1)
            dbus_cmd = (
                "dbus-send --session --dest=com.deepin.Autotool "
                "--print-reply  /com/deepin/Autotool com.deepin.Autotool"
            )
            popen(f'{dbus_cmd}.setText string:"{message}"')
            sleep(0.5)
            # 粘贴
            # popen(f"{dbus_cmd}.getText")
            # 有些地方可能不支持ctrl+v粘贴，比如终端，需要使用ctrl+shift+v
            _hk = ["ctrl", "v"]
            if wayland_shift:
                _hk.insert(1, "shift")
            cls.hot_key(*_hk)
        sleep(1)

    @classmethod
    def press_key(cls, key: str, interval=0.0):
        """
         键盘上指定的按键
        :param key: 键盘按键
        :param interval:
        :return:
        """
        logger.debug(f"点击键盘上指定的按键<{key}>, 间隔<{interval}>")
        pyautogui.press(key, interval=interval)
        sleep(0.1)

    @classmethod
    def press_key_down(cls, key: str):
        """
         按住键盘按键不放
        :param key: 键盘按键
        :return:
        """
        logger.debug(f"按下<{key}>按键")
        pyautogui.keyDown(key)

    @classmethod
    def press_key_up(cls, key: str):
        """
         放松按键
        :param key: 键盘按键
        :return:
        """
        logger.debug(f"放松<{key}>按键")
        pyautogui.keyUp(key)

    @classmethod
    def hot_key(cls, *args, interval=0.03):
        """
         键盘组合按键操作
        :param args: 键盘组合键，比如："ctrl","alt","a"
        :return:
        """
        logger.debug(f"快捷键 {args}")
        pyautogui.hotkey(*args, interval=interval)

    @classmethod
    def hot_key_down(cls, *args):
        """
         组合按键按下不放
        :param args:
        :return:
        """
        for _c in args:
            if len(_c) > 1:
                _c = _c.lower()
            cls.press_key_down(_c)
            sleep(0.03)

    @classmethod
    def hot_key_up(cls, *args):
        """
         组合按键释放
        :param args:
        :return:
        """
        for c in reversed(args):
            if len(c) > 1:
                c = c.lower()
            cls.press_key_up(c)
            sleep(0.03)

    @classmethod
    def move_to_and_click(cls, _x, _y):
        """
         移动到某个位置点击
        :param _x: 移动到的位置 x
        :param _y: 移动到的位置 y
        :return:
        """
        cls.move_to(_x, _y)
        cls.click()

    @classmethod
    def move_to_and_right_click(cls, _x, _y):
        """
         移动到某个位置点击右键
        :param _x: 移动到的位置 x
        :param _y: 移动到的位置 y
        :return:
        """
        cls.move_to(_x, _y)
        cls.right_click()

    @classmethod
    def move_to_and_double_click(cls, _x, _y):
        """
         移动到某个位置点击双击
        :param _x: 移动到的位置 x
        :param _y: 移动到的位置 y
        :return:
        """
        cls.move_to(_x, _y)
        cls.double_click()

    @classmethod
    def move_on_and_drag_to(cls, start: tuple, end: tuple):
        """
         指定拖动的起始-终止坐标
        :param start: 开始坐标
        :param end: 终止坐标
        :return:
        """
        cls.move_to(*start)
        sleep(1)
        cls.drag_to(*end)

    @classmethod
    def move_on_and_drag_rel(cls, start: tuple, end: tuple):
        """
         指定拖动的起始-终止坐标
        :param start: 开始坐标
        :param end: 终止坐标
        :return:
        """
        cls.move_to(*start)
        sleep(1)
        cls.drag_rel(*end)

    @classmethod
    def select_menu(cls, number: int):
        """
         选择桌面右键菜单中的选项(从上到下)
        :param number: 在菜单中的位置数
        :return:
        """
        for _ in range(number):
            cls.press_key("down")
        sleep(0.3)
        cls.press_key("enter")
        logger.debug(f"选择右键菜单中的选项(从上到下)第{number}项")

    @classmethod
    def reverse_select_menu(cls, number: int):
        """
         选择桌面右键菜单中的选项（从下到上）
        :param number: 在菜单中的位置数
        :return:
        """
        for _ in range(number):
            cls.press_key("up")
        sleep(0.3)
        cls.press_key("enter")
        logger.debug(f"选择右键菜单中的选项(从下到上)第{number}项")

    @classmethod
    def select_submenu(cls, number: int):
        """
         选择右键菜单中的子菜单选项（从上到下）
        :param number: 在菜单中的位置数
        :return:
        """
        for _ in range(1, number):
            cls.press_key("down")
        cls.press_key("enter")

    @classmethod
    def locate_all_on_screen(cls, image_path):
        """
         识别所有匹配的图像
        :param image_path: 图像的路径
        :return: 所有匹配的位置的元组组成的列表
        """
        return pyautogui.locateAllOnScreen(image_path)

    @classmethod
    def draw_line(cls, start_x, start_y, rel_x, rel_y):
        """
         从某个坐标开始画线（框选）
        :param start_x: 开始的坐标的横坐标
        :param start_y: 开始的坐标的纵坐标
        :param rel_x: 向量的横坐标
        :param rel_y: 向量的纵坐标
        :return:
        """
        cls.move_to(start_x, start_y)
        cls.drag_rel(rel_x, rel_y)

    @classmethod
    def clear(cls):
        """
         清空表单
        :return:
        """
        logger.debug("清空表单")
        cls.hot_key("ctrl", "a")
        cls.press_key("backspace")



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
import letmego

from src.image_utils import ImageUtils
from src import sleep, log
from src import logger
from src import ShortCut
from public.right_menu_public_widget.config import Config

@letmego.mark
@log
# pylint: disable=too-many-public-methods
class RightMenuPublicWidget(ImageUtils, ShortCut):
    """右键菜单选项
    通过图像识别操作右键菜单
    """

    @classmethod
    def click_right_menu_by_image(cls, pic):
        """
         点击右键菜单中的相应选项
        :param pic: 图片路径
        """
        cls.click(*cls.find_image(f"{Config.PIC_RES_PATH}/{pic}"))

    @classmethod
    def click_always_at_the_top_in_right_menu_by_image(cls):
        """
         点击“总在最前”
        :return:
        """
        cls.click_right_menu_by_image("always_at_the_top")
        logger.info("点击“总在最前”")

    @classmethod
    def click_close_window_in_right_menu_by_image(cls):
        """
         点击“关闭”
        :return:
        """
        cls.click_right_menu_by_image("close")
        logger.info("点击“关闭”")

    @classmethod
    def click_reduction_in_right_menu_by_image(cls):
        """
         点击“还原”
        :return:
        """
        cls.click_right_menu_by_image("reduction")
        logger.info("点击“还原”")

    @classmethod
    def click_minimize_in_right_menu_by_image(cls):
        """
         点击“最小化”
        :return:
        """
        cls.click_right_menu_by_image("minimize")
        logger.info("点击“最小化”")

    @classmethod
    def click_change_size_in_right_menu_by_image(cls):
        """
         点击“更改大小”
        :return:
        """
        cls.click_right_menu_by_image("change_size")
        logger.info("点击“更改大小”")

    @classmethod
    def click_move_in_right_menu_by_image(cls):
        """
         点击“移动”
        :return:
        """
        cls.click_right_menu_by_image("move")
        logger.info("点击“移动”")

    @classmethod
    def click_maximize_in_right_menu_by_image(cls):
        """
         点击“最大化”
        :return:
        """
        cls.click_right_menu_by_image("maximize")
        logger.info("点击“最大化”")

    @classmethod
    def click_always_in_the_visible_workspace_in_right_menu_by_image(cls):
        """
         点击“总在可见工作区”
        :return:
        """
        cls.click_right_menu_by_image("always_in_the_visible_workspace")
        logger.info("点击“总在可见工作区”")

    @classmethod
    def click_move_to_left_workspace_in_right_menu_by_image(cls):
        """
         点击“移至左边工作区“
        :return:
        """
        cls.click_right_menu_by_image("move_to_left_workspace")
        logger.info("点击“移至左边工作区”")

    @classmethod
    def click_move_to_right_workspace_in_right_menu_by_image(cls):
        """
         点击“移至右边工作区“
        :return:
        """
        cls.click_right_menu_by_image("move_to_right_workspace")
        logger.info("点击“移至右边工作区”")

    @classmethod
    def click_open_in_right_menu_by_image(cls):
        """
         点击“打开”
        :return:
        """
        cls.click_right_menu_by_image("open")
        logger.info("点击“打开”")

    @classmethod
    def click_open_mode_in_right_menu_by_image(cls):
        """
         点击“打开方式”
        :return:
        """
        cls.click_right_menu_by_image("open_mode")
        logger.info("点击“打开方式”")

    @classmethod
    def click_attribute_in_right_menu_by_image(cls):
        """
         点击“属性”
        :return:
        """
        cls.click_right_menu_by_image("attribute")
        sleep(1)
        logger.info("点击“属性”")

    @classmethod
    def click_share_manager_in_right_menu_by_image(cls):
        """
         点击“共享管理”
        :return:
        """
        cls.click_right_menu_by_image("share_manager")
        sleep(1)
        logger.info("点击“共享管理”")

    @classmethod
    def click_defender_in_right_menu_by_image(cls):
        """
         点击“病毒查杀”
        :return:
        """
        cls.click_right_menu_by_image("defender")
        logger.info("点击“病毒查杀”")

    @classmethod
    def click_cd_burn_in_right_menu_by_image(cls):
        """
         点击“光盘刻录”
        :return:
        """
        cls.click_right_menu_by_image("CD_burn")
        logger.info("点击“光盘刻录”")

    @classmethod
    def click_compress_in_right_menu_by_image(cls):
        """
         点击“压缩”
        :return:
        """
        cls.click_right_menu_by_image("compress")
        logger.info("点击“压缩”")

    @classmethod
    def click_copy_in_right_menu_by_image(cls):
        """
         点击“复制”
        :return:
        """
        cls.click_right_menu_by_image("copy")
        logger.info("点击“复制”")

    @classmethod
    def click_uncompress_in_right_menu_by_image(cls):
        """
         点击“解压”
        :return:
        """
        cls.click_right_menu_by_image("uncompress")
        logger.info("点击“解压”")

    @classmethod
    def click_paste_in_right_menu_by_image(cls):
        """
         点击“粘贴”
        :return:
        """
        cls.click_right_menu_by_image("paste")
        logger.info("点击“粘贴”")

    @classmethod
    def click_cut_in_right_menu_by_image(cls):
        """
         点击“剪切”
        :return:
        """
        cls.click_right_menu_by_image("cut")
        logger.info("点击“剪切”")

    @classmethod
    def click_delete_in_right_menu_by_image(cls):
        """
         点击“删除”
        :return:
        """
        cls.click_right_menu_by_image("delete")
        logger.info("点击“删除”")

    @classmethod
    def click_create_link_in_right_menu_by_image(cls):
        """
         点击“创建链接”
        :return:
        """
        cls.click_right_menu_by_image("link")
        logger.info("点击“创建链接”")

    @classmethod
    def click_mark_information_in_right_menu_by_image(cls):
        """
         点击“标记信息”
        :return:
        """
        cls.click_right_menu_by_image("mark_information")
        logger.info("点击“标记信息”")

    @classmethod
    def click_new_label_in_right_menu_by_image(cls):
        """
         点击“在新标签中打开”
        :return:
        """
        cls.click_right_menu_by_image("new_label")
        logger.info("点击“在新标签中打开”")

    @classmethod
    def click_copy_path_right_menu_by_image(cls):
        """
         点击“复制路径”
        :return:
        """
        cls.click_right_menu_by_image("copy_path")
        logger.info("点击“复制路径”")

    @classmethod
    def click_edit_path_right_menu_by_image(cls):
        """
         点击“编辑路径”
        :return:
        """
        cls.click_right_menu_by_image("edit_path")
        logger.info("点击“编辑路径”")

    @classmethod
    def click_new_window_in_right_menu_by_image(cls):
        """
         点击“新窗口”
        :return:
        """
        cls.click_right_menu_by_image("new_window")
        logger.info("点击“新窗口”")

    @classmethod
    def click_rename_in_right_menu_by_image(cls):
        """
         点击“重命名”
        :return:
        """
        cls.click_right_menu_by_image("rename")
        logger.info("点击“重命名”")

    @classmethod
    def click_send_to_in_right_menu_by_image(cls):
        """
         点击“发送到”
        :return:
        """
        cls.click_right_menu_by_image("send_to")
        logger.info("点击“发送到”")

    @classmethod
    def click_send_to_uos_in_right_menu_by_image(cls):
        """
         点击“发送到-UOS”
        :return:
        """
        cls.click_right_menu_by_image("UOS")
        logger.info("点击“发送到-UOS”")

    @classmethod
    def click_send_to_desktop_in_right_menu_by_image(cls):
        """
         点击“发送到桌面”
        :return:
        """
        cls.click_right_menu_by_image("send_to_desktop")
        logger.info("点击“发送到桌面”")

    @classmethod
    def click_share_folder_in_right_menu_by_image(cls):
        """
         点击“共享文件夹”
        :return:
        """
        cls.click_right_menu_by_image("share_folder")
        sleep(1)
        logger.info("点击“共享文件夹”")

    @classmethod
    def click_cancel_share_folder_in_right_menu_by_image(cls):
        """
         点击“取消共享文件夹”
        :return:
        """
        cls.click_right_menu_by_image("cancel_share")
        logger.info("点击“取消共享文件夹”")

    @classmethod
    def click_terminal_in_right_menu_by_image(cls):
        """
         点击“终端打开”
        :return:
        """
        cls.click_right_menu_by_image("terminal")
        logger.info("点击“终端打开”")

    @classmethod
    def click_editor_in_right_menu_by_image(cls):
        """
         点击“文本编辑器”
        :return:
        """
        cls.click_right_menu_by_image("editor")
        logger.info("点击“文本编辑器”")

    @classmethod
    def click_file_manager_in_right_menu_by_image(cls):
        """
         点击“文件管理器“
        :return:
        """
        cls.click_right_menu_by_image("file_manager")
        logger.info("点击“文件管理器“")

    @classmethod
    def click_ok_in_right_menu_by_image(cls):
        """
         点击“确定”
        :return:
        """
        cls.click_right_menu_by_image("ok")
        logger.info("点击“确定”")

    @classmethod
    def click_add_bookmark_in_right_menu_by_image(cls):
        """
         点击“添加书签”
        :return:
        """
        cls.click_right_menu_by_image("bookmark")
        logger.info("点击“添加书签”")

    @classmethod
    def click_remove_bookmark_in_right_menu_by_image(cls):
        """
         点击“移除书签”
        :return:
        """
        cls.click_right_menu_by_image("remove_bookmark")
        logger.info("点击“移除书签”")

    @classmethod
    def click_select_default_app_in_right_menu_by_image(cls):
        """
         点击“选择默认程序”
        :return:
        """
        cls.click_right_menu_by_image("select_default_app")
        logger.info("点击“选择默认程序”")

    @classmethod
    def click_open_file_path_in_right_menu_by_image(cls):
        """
         点击“选择打开文件位置”
        :return:
        """
        cls.click_right_menu_by_image("open_file_path")
        logger.info("点击“选择打开文件位置”")

    @classmethod
    def click_open_with_edit_in_right_menu_by_image(cls):
        """
         点击“选择文件编辑器打开”
        :return:
        """
        cls.click_right_menu_by_image("deepin-editor")
        logger.info("点击“选择文件编辑器打开”")

    @classmethod
    def click_remove_in_right_menu_by_image(cls):
        """
         点击“选择移除”
        :return:
        """
        cls.click_right_menu_by_image("remove")
        logger.info("点击“选择移除”")

    @classmethod
    def click_recycle_all_in_right_menu_by_image(cls):
        """
         点击“全部还原”
        :return:
        """
        cls.click_right_menu_by_image("recycle_all")
        logger.info("点击“全部还原”")

    @classmethod
    def click_empty_trash_in_right_menu_by_image(cls):
        """
         点击“清空回收站”
        :return:
        """
        cls.click_right_menu_by_image("empty_trash")
        logger.info("点击“清空回收站”")

    @classmethod
    def click_show_mode_in_right_menu_by_image(cls):
        """
         点击“选择显示方式”
        :return:
        """
        cls.click_right_menu_by_image("show_mode")
        logger.info("点击“选择显示方式”")

    @classmethod
    def click_icon_mode_in_right_menu_by_image(cls):
        """
         点击“选择图标方式”
        :return:
        """
        cls.click_right_menu_by_image("icon_mode")
        logger.info("点击“选择图标方式”")

    @classmethod
    def click_list_mode_in_right_menu_by_image(cls):
        """
         点击“选择列表方式”
        :return:
        """
        cls.click_right_menu_by_image("list_mode")
        logger.info("点击“选择列表方式”")

    @classmethod
    def click_recycle_in_right_menu_by_image(cls):
        """
         点击“选择还原”
        :return:
        """
        cls.click_right_menu_by_image("recycle")
        logger.info("点击“选择还原”")

    @classmethod
    def click_delete_vault_in_right_menu_by_image(cls):
        """
         点击“删除保险箱”
        :return:
        """
        cls.click_right_menu_by_image("delete_vault")
        logger.info("点击“删除保险箱”")

    @classmethod
    def click_lock_now_in_right_menu_by_image(cls):
        """
         点击“立即上锁”
        :return:
        """
        cls.click_right_menu_by_image("lock_now")
        logger.info("点击“立即上锁”")

    @classmethod
    def click_key_unlock_in_right_menu_by_image(cls):
        """
         点击“密钥解锁”
        :return:
        """
        cls.click_right_menu_by_image("key_unlock")
        logger.info("点击“密钥解锁”")

    @classmethod
    def click_set_wallpaper_in_right_menu_by_image(cls):
        """
         点击“设置壁纸”
        :return:
        """
        cls.click_right_menu_by_image("set_wallpaper")
        logger.info("点击“设置壁纸”")

    @classmethod
    def click_open_with_root_in_right_menu_by_image(cls):
        """
         点击“以管理打开”
        :return:
        """
        cls.click_right_menu_by_image("open_with_root")
        logger.info("点击“以管理打开”")

    @classmethod
    def click_new_folder_in_right_menu_by_image(cls):
        """
         点击“新建文件夹”
        :return:
        """
        cls.click_right_menu_by_image("new_folder")
        logger.info("点击“新建文件夹”")

    @classmethod
    def click_auto_sort_in_right_menu_by_image(cls):
        """
         点击“自动排序”
        :return:
        """
        cls.click_right_menu_by_image("auto_sort")
        logger.info("点击“自动排序”")

    @classmethod
    def click_display_setting_in_right_menu_by_image(cls):
        """
         点击“显示设置”
        :return:
        """
        cls.click_right_menu_by_image("display_setting")
        logger.info("点击“显示设置”")

    @classmethod
    def click_excel_in_right_menu_by_image(cls):
        """
         点击“表格”
        :return:
        """
        cls.click_right_menu_by_image("excel")
        logger.info("点击“表格”")

    @classmethod
    def click_icon_size_in_right_menu_by_image(cls):
        """
         点击“图标大小”
        :return:
        """
        cls.click_right_menu_by_image("icon_size")
        logger.info("点击“图标大小”")

    @classmethod
    def click_minist_in_right_menu_by_image(cls):
        """
         点击“极小”
        :return:
        """
        cls.enter()
        cls.select_submenu(1)
        logger.info("点击“极小”")

    @classmethod
    def click_mini_in_right_menu_by_image(cls):
        """
         点击“小”
        :return:
        """
        # cls.click_image("mini")
        cls.enter()
        cls.select_submenu(2)
        logger.info("点击“小”")

    @classmethod
    def click_middle_in_right_menu_by_image(cls):
        """
         点击“中”
        :return:
        """
        # cls.click_image("middle")
        cls.enter()
        cls.select_submenu(3)
        logger.info("点击“中”")

    @classmethod
    def click_big_in_right_menu_by_image(cls):
        """
         点击“大”
        :return:
        """
        # cls.click_image("big")
        cls.enter()
        cls.select_submenu(4)
        logger.info("点击“大”")

    @classmethod
    def click_bigist_in_right_menu_by_image(cls):
        """
         点击“极大”
        :return:
        """
        cls.click_right_menu_by_image("bigist")
        logger.info("点击“极大”")

    @classmethod
    def click_name_in_right_menu_by_image(cls):
        """
         点击“名称”
        :return:
        """
        cls.click_right_menu_by_image("name")
        logger.info("点击“名称”")

    @classmethod
    def click_path_in_right_menu_by_image(cls):
        """
         点击“路径”
        :return:
        """
        cls.click_right_menu_by_image("path")
        logger.info("点击“路径”")

    @classmethod
    def click_latest_visit_time_in_right_menu_by_image(cls):
        """
         点击“最近访问时间”
        :return:
        """
        cls.click_right_menu_by_image("latest_visit_time")
        logger.info("点击“最近访问时间”")

    @classmethod
    def click_new_document_in_right_menu_by_image(cls):
        """
         点击“新建文档”
        :return:
        """
        cls.click_right_menu_by_image("new_document")
        sleep(1)
        logger.info("点击“新建文档”")

    @classmethod
    def click_ppt_in_right_menu_by_image(cls):
        """
         点击“ppt”
        :return:
        """
        cls.click_right_menu_by_image("ppt")
        logger.info("点击“ppt”")

    @classmethod
    def click_select_all_in_right_menu_by_image(cls):
        """
         点击“全选”
        :return:
        """
        cls.click_right_menu_by_image("select_all")
        logger.info("点击“全选”")

    @classmethod
    def click_size_in_right_menu_by_image(cls):
        """
         点击“大小”
        :return:
        """
        cls.click_right_menu_by_image("size")
        logger.info("点击“大小”")

    @classmethod
    def click_word_size_in_right_menu_by_image(cls):
        """
         点击“文件大小”
        :return:
        """
        cls.click_right_menu_by_image("word_size")
        logger.info("点击“文件大小”")

    @classmethod
    def click_word_type_in_right_menu_by_image(cls):
        """
         点击“类型”
        :return:
        """
        cls.click_right_menu_by_image("word_type")
        logger.info("点击“类型”")

    @classmethod
    def click_original_path_in_right_menu_by_image(cls):
        """
         点击“原始路径”
        :return:
        """
        cls.click_right_menu_by_image("original_path")
        logger.info("点击“原始路径”")

    @classmethod
    def click_delete_time_in_right_menu_by_image(cls):
        """
         点击“删除时间”
        :return:
        """
        cls.click_right_menu_by_image("delete_time")
        sleep(1)
        logger.info("点击“删除时间”")

    @classmethod
    def click_sort_method_in_right_menu_by_image(cls):
        """
         点击“排序方法”
        :return:
        """
        cls.click_right_menu_by_image("sort_method")
        sleep(1)
        logger.info("点击“排序方法”")

    @classmethod
    def click_change_time_in_right_menu_by_image(cls):
        """
         点击“修改时间”
        :return:
        """
        cls.click_right_menu_by_image("time")
        logger.info("点击“修改时间”")

    @classmethod
    def click_txt_in_right_menu_by_image(cls):
        """
         点击“txt”
        :return:
        """
        cls.click_right_menu_by_image("txt")
        logger.info("点击“txt”")

    @classmethod
    def click_type_in_right_menu_by_image(cls):
        """
         点击“类型”
        :return:
        """
        cls.click_right_menu_by_image("type")
        logger.info("点击“类型”")

    @classmethod
    def click_wallpaper_in_right_menu_by_image(cls):
        """
         点击“壁纸”
        :return:
        """
        cls.click_right_menu_by_image("wallpaper")
        logger.info("点击“壁纸”")

    @classmethod
    def click_word_in_right_menu_by_image(cls):
        """
         点击“word”
        :return:
        """
        cls.click_right_menu_by_image("word")
        logger.info("点击“word”")

    @classmethod
    def click_default_application_by_image(cls):
        """
         点击“选择默认程序”
        :return:
        """
        cls.click_right_menu_by_image("default_application")
        sleep(1)
        logger.info("点击“选择默认程序”")

    @classmethod
    def click_add_dir_to_zip_by_image(cls):
        """
         点击 ”添加到新建文件夹.zip”
        :return:
        """
        cls.click_right_menu_by_image("add_to_zip")
        logger.info("点击 添加到新建文件夹.zip")

    @classmethod
    def click_add_desktop_zip_by_image(cls):
        """
         点击 “添加到Desktop.zip”
        :return:
        """
        cls.click_right_menu_by_image("add_desktop_zip")
        logger.info("点击 添加到Desktop.zip")

    @classmethod
    def click_list_view_in_right_menu_by_image(cls):
        """
         点击“列表视图“
        :return:
        """
        cls.click_right_menu_by_image("list_view")
        logger.info("点击“列表视图”")

    @classmethod
    def click_icon_view_in_right_menu_by_image(cls):
        """
         点击“图标视图”
        :return:
        """
        cls.click_right_menu_by_image("icon_view")
        logger.info("点击“图标视图”")

    @classmethod
    def click_noanonymity_in_right_menu_by_image(cls):
        """
         点击不允许下拉框
        :return:
        """
        cls.click_right_menu_by_image("no_anonymity")
        logger.info("点击不允许下拉框")

    @classmethod
    def click_anonymity_in_right_menu_by_image(cls):
        """
         点击下拉框的允许选项
        :return:
        """
        cls.click_right_menu_by_image("anonymity")
        logger.info("点击下拉框的允许选项")



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
import letmego

from src import Src, log
from public.right_menu_public_widget.right_menu_public_widget import (
    RightMenuPublicWidget,
)
from public.other_public_widget.config import Config

@letmego.mark
@log
# pylint: disable=too-many-ancestors
class DeepinManualPublicWidget(Src, RightMenuPublicWidget):
    """DeepinManualPublicWidget"""
    APP_NAME = "deepin-manual"
    DESC = "/usr/bin/dman"

    def __init__(self):
        kwargs = {}
        kwargs["name"] = self.APP_NAME
        kwargs["description"] = self.DESC
        kwargs["check_start"] = True
        kwargs["config_path"] = Config.UI_INI_PATH
        Src.__init__(self, **kwargs)

    @classmethod
    def find_help_element_image(cls, *elements):
        """
         通过图片查找帮助元素坐标
        :param elements:
        :return:
        """
        element = tuple(
            map(lambda x: f"{Config.PIC_RES_PATH}/help/elements/{x}", elements)
        )
        return cls.find_image(*element)

    def click_close_btn_in_help_title_by_attr(self):
        """
         标题栏上点击“X“关闭帮助窗口
        :return:
        """
        self.dog.find_element_by_attr(
            "$/DMainWindow/DMainWindowTitlebar/DTitlebarRightArea/"
            "DTitlebarButtonArea//DTitlebarDWindowCloseButton"
        ).click()


if __name__ == "__main__":
    DeepinManualPublicWidget().click_close_btn_in_help_title_by_attr()



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
import json
from os.path import exists
from os import makedirs
from re import findall, sub

from setting.globalconfig import GlobalConfig
from src  import logger
from src.requestx import RequestX

MAX_CASE_NUMBER = 10000
# pylint: disable=unnecessary-lambda-assignment,R0903
runs_id_cmd_log = lambda x: sub(r"'run_case_id': '\d+', ", "", str(x))


class _Base:
    __author__ = "huangmingqiang@uniontech.com"

    def __init__(self, user=None, password=None):
        login_url = "https://pms.uniontech.com/user-login-Lw==.html"
        headers = {"content-type": "application/x-www-form-urlencoded; charset=UTF-8"}
        data = {
            "account": user if user else GlobalConfig.PMS_USER,
            "password": password if password else GlobalConfig.PMS_PASSWORD,
            "passwordStrength": "1",
            "referer": "/zentao/",
            "verifyRand": "370729017",
            "keepLogin": "0",
        }
        # pylint: disable=invalid-name
        self.rx = RequestX(login_url=login_url, headers=headers, data=data)


def _unicode_to_cn(in_str):
    """
    修改数据并进行编码解码操作，以完成u码转中文
    :param in_str: 字符串
    :return:/
    """
    local_in_str_replace = (
        in_str.replace(r"\"", '"')
        .replace(r"\/", "/")
        .replace(r"\\u", r"\u")
        .replace(r"\\n", "")
        .replace(r"\\r", "")
    )
    if isinstance(local_in_str_replace, bytes):
        local_temp = str(local_in_str_replace, encoding="utf-8")
        local_out = local_temp.encode("utf-8").decode("unicode_escape")
    else:
        local_out = local_in_str_replace.encode("utf-8").decode("unicode_escape")
    return (
        local_out.replace('"data":"{', '"data":{')
        .replace('","md5"', ',"md5"')
        .replace(":null", ':"null"')
        .replace(":true", ':"true"')
        .replace(":false", ':"false"')
    )


def write_case_result(item, report):
    """写用例执行的结果"""
    case_result_tpl = {
        "at_case_id": None,
        "case_id": None,
        "from_case_id": None,
        "task_id": None,
        "run_case_id": None,
        "result": None,
    }
    try:
        at_case_id = findall(r"test_.*?_(\d+)", item.name)[0]
    except IndexError:
        return
    taskid = item.config.option.task_id
    suiteid = item.config.option.suite_id
    caseid = None
    run_case_id = None
    from_case_id = None
    for mark in item.own_markers:
        if mark.args == ("PMS用例ID",):
            caseid = mark.name
        elif mark.args == ("run_case_id",):
            run_case_id = mark.name
        elif mark.args == ("from_case_id",):
            from_case_id = mark.name

    if None in (caseid, run_case_id):
        logger.error(f"{item.name},case_id 或 run_case_id 没获取到")

    case_result_tpl["run_case_id"] = run_case_id
    case_result_tpl["case_id"] = caseid
    case_result_tpl["from_case_id"] = from_case_id
    case_result_tpl["task_id"] = taskid or suiteid
    case_result_tpl["at_case_id"] = at_case_id
    case_result_tpl["result"] = "pass" if report.outcome == "passed" else "fail"
    case_res_path = item.session.case_res_path
    if not exists(case_res_path):
        makedirs(case_res_path)
    with open(f"{case_res_path}/{item.name}.json", "w+", encoding="utf-8") as _f:
        _f.write(json.dumps(case_result_tpl, indent=2, ensure_ascii=False))



# -*- coding: utf-8 -*-

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114
from os.path import join
from os.path import dirname
from os.path import abspath

from setting.globalconfig import _GlobalConfig
from setting.globalconfig import GetCfg


class _Config(_GlobalConfig):
    """
    Application library configuration
    """

    # pylint: disable=too-few-public-methods
    class DirName:
        """DirName"""

        # pylint: disable=too-few-public-methods
        class SubDirName:
            """SubDirName"""
            UI_INI = "ui.ini"
            PIC_RES = "pic_res"

    ABSOLUTE_BASE_PATH = dirname(abspath(__file__))
    # res 目录下子目录绝对路径
    UI_INI_PATH = join(ABSOLUTE_BASE_PATH, DirName.SubDirName.UI_INI)
    PIC_RES_PATH = join(ABSOLUTE_BASE_PATH, DirName.SubDirName.PIC_RES)
    # config ini object
    CONFIG_FILE_PATH = join(ABSOLUTE_BASE_PATH, "config.ini")
    cfg = GetCfg(CONFIG_FILE_PATH, "config")

    # config.ini
    # SMB_URL = cfg.get("SMB_URL")


Config = _Config()



#!/usr/bin/env python3
# _*_ coding:utf-8 _*_

# SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.

# SPDX-License-Identifier: GPL-2.0-only
# pylint: disable=C0114,C0301,C0116,W0707,R0903
import json
import re
from collections import deque

from src.pms._base import _Base
from src.pms._base import _unicode_to_cn
from src.pms._base import MAX_CASE_NUMBER


class Task(_Base):
    """获取测试套件关联的用例"""

    __author__ = "huangmingqiang@uniontech.com"

    def get_task_data(self, task_id):
        task_json_url = f"https://pms.uniontech.com/testtask-cases-{task_id}-all-0-id_desc-4-{MAX_CASE_NUMBER}-1.json"
        res = self.rx.open_url(task_json_url)
        res_str = _unicode_to_cn(res)
        try:
            res_dict = json.loads(res_str)
        except json.decoder.JSONDecodeError:
            raise EnvironmentError(f"{task_json_url} 未获取到有效数据！\n 请检查你的PMS账号密码是否正确。")
        runs = res_dict.get("data").get("runs")
        runs_ids = deque()
        for run_case_id in runs:
            # 产品库ID
            case_id = runs.get(run_case_id).get("case")
            # 用例库ID
            from_case_id = runs.get(run_case_id).get("fromCaseID")
            case_title = runs.get(run_case_id).get("title")
            at_case_id = re.findall(r"\[(\d{3})\]", case_title)
            try:
                at_case_id = at_case_id[0]
            except IndexError:
                at_case_id = "   "
            runs_ids.append(
                {
                    "at_case_id": at_case_id,
                    "case_id": case_id,
                    "from_case_id": from_case_id,
                    "run_case_id": run_case_id,
                    "case_title": case_title,
                }
            )
        return runs_ids
